<?php
/**
 * @package JMForm
 * @link http://www.maruny.cat/jmform
 * @license GNU/GPL
 */

// no direct access

defined( '_JEXEC' ) or die( 'Restricted access' );

jimport( 'joomla.application.component.model' );

/**
 * JMForm Model
 * @package JMForm
 */
class JmformModelJmform extends JModel
{
	/**
	 * JMForm entry array
	 * @var array
	 */

	var $_data = null;
	var $_idForm = null;	
	
	/**
	 * Constructor, ens dona l'ID que es passa a l'URL com a variable
	 * @access public
	 * @return void
	 */
	function __construct()
	{
	    parent::__construct();
	
	    $array = JRequest::getVar('nom',  0, '', 'array');
	    $this->setIdForm((int)$array[0]);
	}
	
	/**
 	 * Metode que afegeix un ID de formulari
 	 * @access public
 	 * @param Identificador (int) del formulari
 	 * @return void
 	 */
	function setIdForm($id)
	{
    	// Afegeix l'ID
    	$this->_idForm = $id;
	}
	
	/**
 	 * Metode que obte un ID de formulari
 	 * @access public
 	 * @return int Identificador de formulari
 	 */
	function getIdForm()
	{
    	return $this->_idForm;
	}
	
	/**
	 * Fa una consulta a la base de dades de camps
	 * @return Un string que utilitzarem per treure la informacio de la taula
	 */
	function _buildQuery()
	{
		$query = "SELECT * FROM #__jmform_camps"
		. " WHERE published = 1 and id_formulari = ".$this->_idForm
		. " ORDER BY ordre";
	
		return $query;
	}
	
	/**
	 * Retorna els camps del formulari
	 * @return Array d'objectes que conte la informacio de la base de dades
	 */
	function getData()
	{
		//Comprova que el formulari existeixi i estigui publicat
		if( !$this->existeixForm($this->_idForm) || !$this->publicat($this->_idForm) ) {
			JError::raiseError( 404, JText::_("no existeix formulari") );
		}
				
		if (empty( $this->_data ))
		{
			$query = $this->_buildQuery();
			$this->_data = $this->_getList( $query );
		}
		return $this->_data;
	}
	
	/**
	 * Ens diu si el formulari existeix a la base de dades o no
	 * @return Cert si existeix el formulari a la BD
	 */
	function existeixForm($id)
	{
		$existeix = true;
		$db =& JFactory::getDBO();
		
		$query = "SELECT id FROM #__jmform_formularis"
		. " WHERE id = ".$id;
		$db->setQuery($query);
		$idForm = $db->loadResult();
		
		if ($idForm == null) $existeix = false;
		
		return $existeix;
	}
	
	/**
	 * Ens diu si el formulari esta publicat o no
	 * @return Cert si el formulari esta publicat
	 */
	function publicat($id)
	{
		$db =& JFactory::getDBO();
		
		$query = "SELECT published FROM #__jmform_formularis"
		. " WHERE id = ".$id;
		$db->setQuery($query);
		$publicat = $db->loadResult();
		
		return $publicat;
	}
	
	/**
	 * Retorna la URL d'agraiment
	 * @return Text que conte la URL
	 */
	function getUrlAgraiment($id)
	{
		$db =& JFactory::getDBO();
		
		$query = "SELECT url_agraiment FROM #__jmform_formularis"
		. " WHERE id = ".$id;
		$db->setQuery($query);
		$url = $db->loadResult();
		
		return $url;
	}
	
	/**
	 * Retorna la URL a mostrar quan el formulari no est entre les dates de publicacio
	 * @return Text que conte la URL
	 */
	function getUrlData($id)
	{
		$db =& JFactory::getDBO();
		
		$query = "SELECT url_data FROM #__jmform_formularis"
		. " WHERE id = ".$id;
		$db->setQuery($query);
		$url = $db->loadResult();
		
		return $url;
	}
	
	/**
	 * Retorna el correu electronic si volem ser avisats, altrament torna null
	 * @return El correu electroni o null
	 */
	function getEmail($id)
	{
		$db =& JFactory::getDBO();
		
		$query = "SELECT avisar_noves_entrades, email_noves_entrades FROM #__jmform_formularis"
		. " WHERE id = ".$id;
		$db->setQuery($query);
		$emails = $db->loadRow();
		
		($emails[0] && $emails[1]!= '') ? $email = $emails[1] : $email = null;
		return $email;
	}
	
	/**
	 * Retorna Les dates de inici i de fi de publicacio del formulari
	 * @return Array amb les dates de inici i de fi
	 */
	function getDates($id)
	{
		$db =& JFactory::getDBO();
		
		$query = "SELECT data_inici, data_fi FROM #__jmform_formularis"
		. " WHERE id = ".$id;
		$db->setQuery($query);
		$dates = $db->loadRow();
		
		return $dates;
	}
	
	/**
	 * Metode que guarda un resultat de formulari
   * @access public
   * @return Cert si finalitza correctament
 	 */
	function store($data)
	{    	
    	$row =& $this->getTable('resultatstaula');
			$data->data = date('Y-m-d H:i:s');
			
			$user =& JFactory::getUser();
			if($user->get('id')) {
					$data->id_usuari = $user->get('id');
			}
    	
    	// Comprova la correspondencia dels camps del formulari amb la taula
    	if (!$row->bind($data)) {
       	 	$this->setError($this->_db->getErrorMsg());
        	return false;
    	}
		
		  // Comprovem que les dades siguin correctes
	    if (!$row->check()) {
	        $this->setError($this->_db->getErrorMsg());
	        return false;
	    }
		
   		// Guardem el formulari a la base de dades
    	if (!$row->store()) {
        	$this->setError($this->_db->getErrorMsg());
        	return false;
    	}
    	
    	// Enviem un correu electronic per avisar del resultat del formulari
    	$email = $this->getEmail( $data->id_formulari );
    	if ($email != null) {
    		// Fetch the mail object
    		$mailer =& JFactory::getMailer();
    		
    		// Afegim les dades de qui envia el correu
    		$config =& JFactory::getConfig();
				$sender = array(
					$config->getValue( 'config.mailfrom' ),
					$config->getValue( 'config.fromname' ) );
				$mailer->setSender($sender);
				
				// Direccio de enviament, assumpte i cos del missatge
				$mailer->addRecipient($email);
				$cos = JText::_("COS CORREU").' '.$data->data;
				$mailer->setSubject(JText::_("ASUMPTE CORREU"));
				$mailer->setBody($cos);
				
				// Enviem el correu
				$send =& $mailer->Send();
				if ( $send !== true ) {
					echo JText::_("ERROR CORREU").' '. $send->message;
				} else {
					echo JText::_("CORREU ENVIAT");
				}
    	}

    	return true;
	}

}
